@@ -1,19 +1,19 @@
 
-#define HOST_CPU "i586"
+#define HOST_CPU "i486"
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.0.34"
+#define HOST_OS_VERSION "2.2.10"
 #define HOST_ARCH "i386"
-#define HOST_NAME "hyena.mcl.cs.columbia.edu"
+#define HOST_NAME "holstein.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Sep  8 18:47:23 EDT 1999"
+#define CONFIG_DATE "Tue Jul  4 18:14:42 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.1"
+#define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.1"
+#define VERSION "6.0.4s6"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.0.36"
+#define HOST_HEADER_VERSION "2.2.5-22"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
@@ -49,6 +49,7 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
+#define HAVE_SETITIMER 1
 #define HAVE_SETRESUID 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
@@ -67,6 +68,7 @@
 #define HAVE_UNAME 1
 #define HAVE_UMOUNT 1
 #define HAVE_VFORK 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -120,8 +122,11 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_DB1_NDBM_H 1
 #define HAVE_LINUX_AUTO_FS_H 1
 #define HAVE_LINUX_FS_H 1
+#define HAVE_LINUX_KDEV_T_H 1
+#define HAVE_LINUX_LIST_H 1
 #define HAVE_LINUX_NFS_H 1
 #define HAVE_LINUX_NFS_MOUNT_H 1
 #define HAVE_LINUX_POSIX_TYPES_H 1
@@ -138,6 +143,7 @@
 #define HAVE_RPC_XDR_H 1
 #define HAVE_RPCSVC_MOUNT_H 1
 #define HAVE_RPCSVC_NFS_PROT_H 1
+#define HAVE_RPCSVC_NIS_H 1
 #define HAVE_RPCSVC_YP_PROT_H 1
 #define HAVE_RPCSVC_YPCLNT_H 1
 #define HAVE_SYS_DIR_H 1
@@ -167,15 +173,12 @@
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_MNTENT_H 1
-#define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
 #define HAVE_PWD_H 1
 #define HAVE_REGEX_H 1
 #define HAVE_RESOLV_H 1
 #define HAVE_SETJMP_H 1
 #define HAVE_SIGNAL_H 1
-#define HAVE_SOCKETBITS_H 1
-#define HAVE_STATBUF_H 1
 #define HAVE_STDARG_H 1
 #define HAVE_STDLIB_H 1
 #define HAVE_STDIO_H 1
@@ -186,11 +189,10 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_linux.h"
 #define HAVE_STRUCT_MNTENT 1
-#define HAVE_STRUCT_NFS_MOUNT_DATA 1
-#define nfs_args_t struct nfs_mount_data
+#define HAVE_STRUCT_NFS_ARGS 1
+#define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD root
 #define am_nfs_fh nfs_fh
 #define GETGROUPS_T gid_t
@@ -220,52 +222,57 @@
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
+#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_FIELD_NFS_ARGS_T_BSIZE 1
+#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
+#define HAVE_FIELD_NFS_ARGS_T_NAMLEN 1
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_UMNTREQUEST_RDEVID 1
 #define HAVE_MAP_FILE 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
+#define HAVE_MAP_NISPLUS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
-#define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
-#define HAVE_AM_FS_AUTO 1
-#define HAVE_AM_FS_DIRECT 1
-#define HAVE_AM_FS_TOPLVL 1
-#define HAVE_AM_FS_ERROR 1
-#define HAVE_AM_FS_INHERIT 1
-#define HAVE_AM_FS_PROGRAM 1
-#define HAVE_AM_FS_LINK 1
-#define HAVE_AM_FS_LINKX 1
-#define HAVE_AM_FS_HOST 1
-#define HAVE_AM_FS_NFSX 1
-#define HAVE_AM_FS_NFSL 1
-#define HAVE_AM_FS_UNION 1
+#define HAVE_AMU_FS_AUTO 1
+#define HAVE_AMU_FS_DIRECT 1
+#define HAVE_AMU_FS_TOPLVL 1
+#define HAVE_AMU_FS_ERROR 1
+#define HAVE_AMU_FS_INHERIT 1
+#define HAVE_AMU_FS_PROGRAM 1
+#define HAVE_AMU_FS_LINK 1
+#define HAVE_AMU_FS_LINKX 1
+#define HAVE_AMU_FS_HOST 1
+#define HAVE_AMU_FS_NFSX 1
+#define HAVE_AMU_FS_NFSL 1
+#define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
 #define MOUNT_TYPE_UFS "ext2"
-#define MOUNT_TYPE_CDFS "isofs"
+#define MOUNT_TYPE_CDFS "iso9660"
 #define MOUNT_TYPE_PCFS "vfat"
-#define MOUNT_TYPE_AUTOFS "autofs"
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
+#define MNTTAB_TYPE_NFS3 "nfs"
 #define MNTTAB_TYPE_UFS "ext2"
-#define MNTTAB_TYPE_CDFS "isofs"
+#define MNTTAB_TYPE_CDFS "iso9660"
 #define MNTTAB_TYPE_PCFS "vfat"
-#define MNTTAB_TYPE_AUTOFS "autofs"
 #define MNTTAB_OPT_NOAUTO "noauto"
 #define MNTTAB_OPT_NOSUID "nosuid"
 #define MNTTAB_OPT_RO "ro"
@@ -282,6 +289,7 @@
 #define MNT2_NFS_OPT_POSIX 0x8
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_TCP 0x40
+#define MNT2_NFS_OPT_VER3 0x80
 #define HIDE_MOUNT_TYPE "nfs"
 #define MOUNT_TABLE_ON_FILE 1
 #define MNTTAB_FILE_NAME "/etc/mtab"
